pyrsl |Build Status| |Coverage Status|
======================================

pyrsl is an interpreter for a language called RSL (Rule Specification Language).
RSL is commonly used as a template language to express transformations from a
`BridgePoint <https://www.xtuml.org>`__ model into a textual representation,
e.g. when writing model compilers or when generating html documentation from a
model.

Documentation
~~~~~~~~~~~~~
Information on how to install and use pyrsl is available at `Read the Docs
<http://pyrsl.readthedocs.io>`__.

Reporting bugs
~~~~~~~~~~~~~~
If you encounter problems with pyrsl, please `file a github
issue <https://github.com/xtuml/pyrsl/issues/new>`__. If you plan on
sending pull request which affect more than a few lines of code, please file an
issue before you start to work on you changes. This will allow us to discuss the
solution properly before you commit time and effort.

License
~~~~~~~
pyrsl is licensed under the GPLv3, see LICENSE for more information.

.. |Build Status| image:: https://travis-ci.org/xtuml/pyrsl.svg?branch=master
   :target: https://travis-ci.org/xtuml/pyrsl
.. |Coverage Status| image:: https://coveralls.io/repos/xtuml/pyrsl/badge.svg?branch=master
   :target: https://coveralls.io/r/xtuml/pyrsl?branch=master

